@@ -21,8 +21,9 @@
 
 #include "dialog_fieldcalculation.h"
 #include "../../box_db_table.h"
-#include "../../frame_glom.h"
-#include "../../python_embed/glom_python.h"
+#include <glom/frame_glom.h>
+#include <glom/python_embed/glom_python.h>
+#include <glom/utils_ui.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <gtksourceviewmm/sourcelanguagemanager.h>
 
@@ -32,6 +33,9 @@
 namespace Glom
 {
 
+const char* Dialog_FieldCalculation::glade_id("window_field_calculation");
+const bool Dialog_FieldCalculation::glade_developer(true);
+
 Dialog_FieldCalculation::Dialog_FieldCalculation(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject)
 {
@@ -98,7 +102,7 @@ bool Dialog_FieldCalculation::check_for_return_statement(const Glib::ustring& ca
      Frame_Glom::show_ok_dialog(_("Calculation Error"), _("The calculation does not have a return statement."), *this);
      return false;
   }
-  
+
   return true;
 }
 
@@ -125,11 +129,21 @@ void Dialog_FieldCalculation::on_button_test()
   //We need the connection when we run the script, so that the script may use it.
   sharedptr<SharedConnection> sharedconnection = connect_to_server(this /* parent window */);
 
-  const Gnome::Gda::Value value = glom_evaluate_python_function_implementation(Field::TYPE_TEXT, calculation, field_values, //TODO: Maybe use the field's type here.
-    document, m_table_name, sharedconnection->get_gda_connection());
-
-  Frame_Glom::show_ok_dialog(_("Calculation result"), _("The result of the calculation is:\n") + value.to_string(), *this);
+  Glib::ustring error_message;
+  const Gnome::Gda::Value value = glom_evaluate_python_function_implementation(
+    Field::TYPE_TEXT,
+    calculation,
+    field_values, //TODO: Maybe use the field's type here.
+    document,
+    m_table_name,
+    sharedptr<Field>(), Gnome::Gda::Value(), // primary key - only used when setting values in the DB.
+    sharedconnection->get_gda_connection(),
+    error_message);
 
+  if(error_message.empty())
+    Utils::show_ok_dialog(_("Calculation result"), _("The result of the calculation is:\n") + value.to_string(), *this, Gtk::MESSAGE_INFO);
+  else
+    Utils::show_ok_dialog(_("Calculation failed"), _("The calculation failed with this error:\n") + error_message, *this, Gtk::MESSAGE_ERROR);
 
   //Show what fields would trigger the recalculation:
   sharedptr<Field> temp = sharedptr<Field>::create();
@@ -155,6 +169,3 @@ void Dialog_FieldCalculation::on_button_test()
 }
 
 } //namespace Glom
-
-
-
