@@ -18,8 +18,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef GLOM_NOTEBOOK_FIND_H
-#define GLOM_NOTEBOOK_FIND_H
+#ifndef NOTEBOOK_FIND_H
+#define NOTEBOOK_FIND_H
 
 #include "../mode_data/notebook_data.h"
 #include "box_data_list_find.h"
@@ -42,13 +42,13 @@ public:
    * should be used to find and display records.
    * @param find_criteria The SQL where clause.
    */
-  sigc::signal<void, Glib::ustring> signal_find_criteria;
+  sigc::signal<void, Gnome::Gda::SqlExpr> signal_find_criteria;
 
 private:
 
 
   //Signal handlers:
-  void on_page_find_criteria(const Glib::ustring& where_clause);
+  void on_page_find_criteria(const Gnome::Gda::SqlExpr& where_clause);
 
   //Member widgets:
   #ifndef GLOM_ENABLE_MAEMO
@@ -63,4 +63,4 @@ private:
 
 } //namespace Glom
 
-#endif // GLOM_NOTEBOOK_FIND_H
+#endif
