@@ -30,6 +30,7 @@
 #include <glom/utility_widgets/canvas/canvas_image_movable.h>
 #include <glom/utility_widgets/canvas/canvas_text_movable.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <libglom/db_utils.h>
 
 #include <glom/glade_utils.h>
 #include <glibmm/i18n.h>
@@ -610,7 +611,7 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
       if(layoutitem_portal)
       {
         //Fill the related records table:
-        sharedptr<Relationship> relationship = layoutitem_portal->get_relationship();
+        sharedptr<const Relationship> relationship = layoutitem_portal->get_relationship();
         if(relationship)
         {
           sharedptr<Field> from_field = get_fields_for_table_one_field(relationship->get_from_table(), relationship->get_from_field());
@@ -624,14 +625,10 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
   if(fieldsToGet.empty())
     return;
 
-  Glib::ustring sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
+  Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
     fieldsToGet,
-    found_set.m_where_clause, Glib::ustring() /* extra_join */, found_set.m_sort_clause);
-
-  if(!sql_query.empty())
-    sql_query += " LIMIT 1";
-  else
-    return;
+    found_set.m_where_clause, sharedptr<const Relationship>() /* extra_join */, found_set.m_sort_clause,
+    1);
   
   bool records_found = false;
   Glib::RefPtr<Gnome::Gda::DataModel> datamodel;
@@ -639,7 +636,7 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
   try
   {
   #endif
-    datamodel = query_execute_select(sql_query);
+    datamodel = DbUtils::query_execute_select(sql_query);
   #ifdef GLIBMM_EXCEPTIONS_ENABLED
   }
   catch(const Glib::Exception& ex)
@@ -734,9 +731,9 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
   found_set.m_table_name = portal->get_table_used(Glib::ustring() /* parent table_name, not used. */);
   set_found_set_where_clause_for_portal(found_set, portal, foreign_key_value);
 
-  const Glib::ustring sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name, fields_shown, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause, found_set.m_extra_group_by);
+  Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name, fields_shown, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause);
   //std::cout << "DEBUG: sql_query=" << sql_query << std::endl;
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query);
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(sql_query);
   if(!(datamodel))
     return;
     
