@@ -1,5 +1,6 @@
 #include <glom/libglom/init.h>
 #include <glom/python_embed/glom_python.h>
+#include <iostream>
 
 //Store results from the callbacks and check them later:
 Glib::ustring result_table_name_list;
@@ -11,13 +12,13 @@ bool result_started_new_record = false;
 
 static void on_script_ui_show_table_list(const Glib::ustring& table_name)
 {
-  //std::cout << "debug: on_script_ui_show_table_list(): table_name=" << table_name << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": table_name=" << table_name << std::endl;
   result_table_name_list = table_name;
 }
 
 static void on_script_ui_show_table_details(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value)
 {
-  //std::cout << "debug: on_script_ui_show_table_details(): table_name=" << table_name
+  //std::cout << "debug: " << G_STRFUNC << ": table_name=" << table_name
   //  << ", primary_key_value=" << primary_key_value.to_string() << std::endl;
   result_table_name_details = table_name;
   result_primary_key_value_details = primary_key_value;
@@ -71,6 +72,7 @@ int main()
     sigc::ptr_fun(&on_script_ui_start_new_record);
 
   //Execute a python script:
+  Glib::ustring error_message;
   try
   {
     Glom::glom_execute_python_function_implementation(
@@ -78,7 +80,8 @@ int main()
       0 /* document */, table_name_input,
       Glom::sharedptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
       connection,
-      callbacks);
+      callbacks,
+      error_message);
   }
   catch(const std::exception& ex)
   {
@@ -91,6 +94,8 @@ int main()
     return EXIT_FAILURE;
   }
 
+  g_assert(error_message.empty());
+
   //Check that the callbacks received the expected values:
   g_assert(result_table_name_list == table_name_input);
   g_assert(result_table_name_details == table_name_details_input);
